==> 0.11.0.tar.gz: lib/flutter_waff.dart <==
library flutter_waff;

import 'src/services/db/db_service.dart';
import 'src/services/http/http.dart';

export 'src/components/pull_to_refresh/pull_to_refresh_controller.dart';
export 'src/components/pull_to_refresh/pull_to_refresh_widget.dart';
export 'src/components/show_actions_sheet.dart';
export 'src/components/show_dialogs.dart';
export 'src/components/show_snack_bar.dart';
export 'src/components/swipe_widget/swipe_indicator_widget.dart';
export 'src/components/swipe_widget/swipe_widget.dart';
export 'src/services/db/db_service.dart';
export 'src/services/db/storage_service.dart';
export 'src/services/event_bus.dart';
export 'src/services/http/http.dart';
export 'src/services/http/http_base_options.dart';
export 'src/services/http/http_cancel_token.dart';
export 'src/services/http/http_classic_transformer.dart';
export 'src/services/http/http_error.dart';
export 'src/services/http/http_runner.dart';
export 'src/services/http/http_runner_params.dart';
export 'src/services/http/http_smart_cancel.dart';
export 'src/services/http/http_standard_transformer.dart';
export 'src/services/http/http_transformer.dart';
export 'src/utils/locale_manage.dart';
export 'src/utils/log.dart';
export 'src/utils/request_permission.dart';
export 'src/utils/theme_manage.dart';
export 'src/utils/utils.dart';
export 'src/waff_localizations.dart';

class Waff {
  static void get isDbLogEnable => DbService.isLogEnable;

  static set isDbLogEnable(value) => DbService.isLogEnable = value;

  static void get isHttpLogEnable => Http.isLogEnable;

  static set isHttpLogEnable(value) => Http.isLogEnable = value;

  static void get isHttpFullLogEnable => Http.isFullLogEnable;

  static set isHttpFullLogEnable(value) => Http.isFullLogEnable = value;
}

==> 2.0.0.tar.gz: lib/flutter_waff.dart <==
library flutter_waff;

import 'src/services/db/db_service.dart';
import 'src/services/http/http.dart';

export 'src/components/pull_to_refresh/pull_to_refresh_controller.dart';
export 'src/components/pull_to_refresh/pull_to_refresh_widget.dart';
export 'src/components/show_actions_sheet.dart';
export 'src/components/show_dialogs.dart';
export 'src/components/show_snack_bar.dart';
export 'src/components/swipe_widget/swipe_indicator_widget.dart';
export 'src/components/swipe_widget/swipe_widget.dart';
export 'src/services/db/db_service.dart';
export 'src/services/db/storage_service.dart';
export 'src/services/event_bus.dart';
export 'src/services/http/http.dart';
export 'src/services/http/http_base_options.dart';
export 'src/services/http/http_cancel_token.dart';
export 'src/services/http/http_classic_transformer.dart';
export 'src/services/http/http_error.dart';
export 'src/services/http/http_runner.dart';
export 'src/services/http/http_runner_params.dart';
export 'src/services/http/http_smart_cancel.dart';
export 'src/services/http/http_standard_transformer.dart';
export 'src/services/http/http_transformer.dart';
export 'src/utils/app_lifecycle_listener.dart';
export 'src/utils/connectivity_listener.dart';
export 'src/utils/locale_manage.dart';
export 'src/utils/log.dart';
export 'src/utils/theme_manage.dart';
export 'src/utils/utils.dart';
export 'src/waff_localizations.dart';

class Waff {
  static void get isDbLogEnable => DbService.isLogEnable;

  static set isDbLogEnable(value) => DbService.isLogEnable = value;

  static void get isHttpLogEnable => Http.isLogEnable;

  static set isHttpLogEnable(value) => Http.isLogEnable = value;

  static void get isHttpFullLogEnable => Http.isFullLogEnable;

  static set isHttpFullLogEnable(value) => Http.isFullLogEnable = value;
}
